/**************************************************************************
* This file is part of the WebIssues program
* Copyright (C) 2006 Michał Męciński
* Copyright (C) 2007-2008 WebIssues Team
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
**************************************************************************/

#include "datarows.h"

using namespace WebIssues;

ProjectRow::ProjectRow( int projectId, const QString& name ) :
    m_name( name )
{
    setKey( 0, projectId );
}

ProjectRow::~ProjectRow()
{
}

FolderRow::FolderRow( int folderId, int projectId, const QString& name, int typeId, int stamp ) :
    m_name( name ),
    m_typeId( typeId ),
    m_stamp( stamp )
{
    setKey( 0, folderId );
    setKey( 1, projectId );
}

FolderRow::~FolderRow()
{
}

UserRow::UserRow( int userId, const QString& login, const QString& name, Access access ) :
    m_login( login ),
    m_name( name ),
    m_access( access )
{
    setKey( 0, userId );
}

UserRow::~UserRow()
{
}

MemberRow::MemberRow( int userId, int projectId, Access access ) :
    m_access( access )
{
    setKey( 0, userId );
    setKey( 1, projectId );
}

MemberRow::~MemberRow()
{
}

TypeRow::TypeRow( int typeId, const QString& name ) :
    m_name( name )
{
    setKey( 0, typeId );
}

TypeRow::~TypeRow()
{
}

AttributeRow::AttributeRow( int attributeId, int typeId, const QString& name, const QString& definition ) :
    m_name( name ),
    m_definition( definition )
{
    setKey( 0, attributeId );
    setKey( 1, typeId );
}

AttributeRow::~AttributeRow()
{
}

IssueRow::IssueRow( int issueId, int folderId, const QString& name, int stamp, const QDateTime& createdDate,
        int createdUser, const QDateTime& modifiedDate, int modifiedUser ) :
    m_name( name ),
    m_stamp( stamp ),
    m_createdDate( createdDate ),
    m_createdUser( createdUser ),
    m_modifiedDate( modifiedDate ),
    m_modifiedUser( modifiedUser )
{
    setKey( 0, issueId );
    setKey( 1, folderId );
}

IssueRow::~IssueRow()
{
}

ValueRow::ValueRow( int attributeId, int issueId, const QString& value ) :
    m_value( value )
{
    setKey( 0, attributeId );
    setKey( 1, issueId );
}

ValueRow::~ValueRow()
{
}

CommentRow::CommentRow( int commentId, int issueId, const QDateTime& createdDate, int createdUser,
        const QString& text ) :
    m_createdDate( createdDate ),
    m_createdUser( createdUser ),
    m_text( text )
{
    setKey( 0, commentId );
    setKey( 1, issueId );
}

CommentRow::~CommentRow()
{
}

AttachmentRow::AttachmentRow( int attachmentId, int issueId, const QString& name, const QDateTime& createdDate,
        int createdUser, int size, const QString& description ) :
    m_name( name ),
    m_createdDate( createdDate ),
    m_createdUser( createdUser ),
    m_size( size ),
    m_description( description )
{
    setKey( 0, attachmentId );
    setKey( 1, issueId );
}

AttachmentRow::~AttachmentRow()
{
}

ChangeRow::ChangeRow( int changeId, int issueId, const QDateTime& modifiedDate, int modifiedUser,
        int attributeId, const QString& oldValue, const QString& newValue ) :
    m_modifiedDate( modifiedDate ),
    m_modifiedUser( modifiedUser ),
    m_attributeId( attributeId ),
    m_oldValue( oldValue ),
    m_newValue( newValue )
{
    setKey( 0, changeId );
    setKey( 1, issueId );
}

ChangeRow::~ChangeRow()
{
}
