/**************************************************************************
* This file is part of the WebIssues program
* Copyright (C) 2006 Michał Męciński
* Copyright (C) 2007-2008 WebIssues Team
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
**************************************************************************/

#ifndef FOLDERWATCHPROVIDER_H
#define FOLDERWATCHPROVIDER_H

#include <QObject>
#include <QList>
#include <QMap>

namespace WebIssues
{

class HTMLWatchWriter;
class ColumnConditionSettings;
class IssueRowFilter;

/**
* Class providing folder watches to the HTMLWatchWriter.
*
* This class calculates the status of folder watches, formats it into localized text
* and outputs it to the HTMLWatchWriter.
*/
class FolderWatchProvider : QObject
{
    Q_OBJECT
public:
    /**
    * Default constructor.
    */
    FolderWatchProvider();

    /**
    * Destructor.
    */
    ~FolderWatchProvider();

public:
    /**
    * Calculate watches for all folders.
    */
    void updateAll();

    /**
    * Calculate watches for all folders of the given type.
    */
    void updateFolders( int typeId );

    /**
    * Calculate watches of a single folder.
    */
    void updateFolder( int folderId );

    /**
    * Return @c true if there are no watches.
    */
    bool isEmpty();

    /**
    * Write the status of the watches to the given writer.
    */
    void write( HTMLWatchWriter* writer );

private:
    void calculateWatches( int folderId, ColumnConditionSettings* settings );

private:
    struct Watch
    {
        QString m_filter;
        int m_total;
        int m_new;
        int m_updated;

        static bool compare( const Watch& w1, const Watch& w2 );
    };

    typedef QList<Watch> WatchList;

private:
    QMap<int, WatchList> m_map;

    IssueRowFilter* m_filter;
};

}

#endif
