/**************************************************************************
* This file is part of the WebIssues program
* Copyright (C) 2006 Michał Męciński
* Copyright (C) 2007-2008 WebIssues Team
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
**************************************************************************/

#ifndef FOLDERVIEW_H
#define FOLDERVIEW_H

#include "view.h"
#include "models/abstracttablemodel.h"

class QTreeView;
class QModelIndex;
class QMenu;
class QActionGroup;

namespace WebIssues
{

class TableItemModel;
class IssueRowFilter;
class SearchEditBox;
class SeparatorComboBox;
class ColumnCondition;

/**
* View for displaying issues in a folder.
*/
class FolderView : public View
{
    Q_OBJECT
public:
    /**
    * Constructor.
    *
    * @param parent The parent object.
    *
    * @param parentWidget The parent widget of the view's main widget.
    */
    FolderView( QObject* parent, QWidget* parentWidget );

    /**
    * Destructor.
    */
    ~FolderView();

public:
    void selectFilter( const QString& filter );

public: // overrides
    void initialUpdate();

protected: // overrides
    void enableView();
    void disableView();

    void updateEvent( UpdateEvent* e );

    void viewEvent( ViewEvent* e );

private slots:
    void updateActions();
    void updateSummary();

    void updateFolder();
    void openIssue();
    void addIssue();
    void changeFilter();
    void saveFilterAs();
    void manageFilters();
    void configureColumns();

    void headerContextMenu( const QPoint& pos );
    void listContextMenu( const QPoint& pos );

    void activated( const QModelIndex& index );

    void quickSearchChanged( const QString& text );
    void searchActionTriggered( QAction* action );
    void filterActivated( int index );

    void applyColumns();
    void applyFilter();

private:
    Access checkDataAccess();

    void updateCaption();

    void updateColumnList();
    void updateFilters();
    void updateSearchOptions();

    void loadCurrentFilter();

    QModelIndex selectedIndex();

private:
    enum FilterType
    {
        NoFilter,
        SettingsFilter,
        NewFilter
    };

private:
    QTreeView* m_list;
    TableItemModel* m_model;

    IssueRowFilter* m_filter;

    SeparatorComboBox* m_filterCombo;

    SearchEditBox* m_searchBox;

    QMenu* m_searchMenu;
    QActionGroup* m_searchActionGroup;

    FilterType m_filterType;
    QString m_filterName;

    QList<ColumnCondition> m_newConditions;

    Column m_searchColumn;

    int m_typeId;
    int m_projectId;

    int m_selectedIssueId;
};

}

#endif
